@@ -26,12 +26,32 @@ static_assert(sizeof(std::unique_ptr<QSerialPortInfoPrivate>)
     \inmodule QtSerialPort
     \since 5.1
 
-    Use the static functions to generate a list of QSerialPortInfo
-    objects. Each QSerialPortInfo object in the list represents a single
-    serial port and can be queried for the port name, system location,
-    description, and manufacturer. The QSerialPortInfo class can also be
-    used as an input parameter for the setPort() method of the QSerialPort
-    class.
+    Use the static \l availablePorts() function to generate a list of
+    QSerialPortInfo objects. Each QSerialPortInfo object in the list represents
+    a single serial port and can be queried for the \l {portName}{port name},
+    \l {systemLocation}{system location}, \l description, \l manufacturer, and
+    some other hardware parameters. The QSerialPortInfo class can also be
+    used as an input parameter for the \l {QSerialPort::}{setPort()} method of
+    the QSerialPort class.
+
+    \section1 Example Usage
+
+    The example code enumerates all available serial ports and prints their
+    parameters to console:
+
+    \snippet doc_src_serialport.cpp enumerate_ports
+
+    \section1 Port enumeration on Linux
+
+    By default Linux uses \c {libudev} to enumerate the available serial ports.
+    If the library is not available, it falls back to reading files in the
+    \c {/sys/class/tty} directory.
+
+    It is known that some versions of \c {libudev} have a bug and incorrectly
+    report VID and PID of a USB hub instead of the actual device. In such cases,
+    define the \c {QT_SERIALPORT_SKIP_UDEV_LOOKUP} environment variable to skip
+    the \c {libudev} lookup and only use the information from the
+    \c {/sys/class/tty} directory.
 
     \sa QSerialPort
 */
@@ -242,6 +262,8 @@ QList<qint32> QSerialPortInfo::standardBaudRates()
     \fn QList<QSerialPortInfo> QSerialPortInfo::availablePorts()
 
     Returns a list of available serial ports on the system.
+
+    \sa {Port enumeration on Linux}
 */
 
 QT_END_NAMESPACE
